@@ -787,11 +787,11 @@ class Sf:
         account_page_layouts_bulk = account_page_layouts_bulk[(~account_page_layouts_bulk['ProfileName'].isnull()) & (account_page_layouts_bulk['ProfileName'] != '') & (account_page_layouts_bulk['PageLayout'] != 'Veeva Vpro Unit Testing Layout')].copy()
         
         if self.instance.__contains__("my.salesforce.com"):
-            sf_meta_instance = self.instance.replace("my.salesforce.com","")
+            sf_meta_instance = self.instance.replace(".my.salesforce.com","")
         else:
             sf_meta_instance = ".".join(self.instance.split(".")[:1])
         
-        account_page_layouts_bulk['Edit Link'] = account_page_layouts_bulk.apply(lambda row: "https://" + sf_meta_instance + ".lightning.force.com/lightning/setup/ObjectManager/" + row['DeveloperName'] + "/PageLayouts/" + row['ProfileLayout.LayoutId'], axis=1)
+        account_page_layouts_bulk['Edit Link'] = account_page_layouts_bulk.apply(lambda row: "https://" + sf_meta_instance + ".lightning.force.com/lightning/setup/ObjectManager/" + row['DeveloperName'] + "/PageLayouts/" + row['ProfileLayout.LayoutId'] + "/view", axis=1)
         
         if return_pivot_table:
             return account_page_layouts_bulk.pivot(index='ProfileName', columns=['DeveloperName','RecordTypeName'], values='PageLayout')
@@ -883,6 +883,47 @@ class Sf:
             nonpermissionable_fields[object] = task_result_dict[object]['fields'].T[task_result_dict[object]['fields'].T['permissionable'] == False].index.tolist()
         return permissionable_fields, nonpermissionable_fields, task_result_dict
     
+    async def get_layout_metadata(self, layout_name):
+        # Layout Name is the Object API Name + Page Layout Name of the layout, for example:
+        # Account-Hospital Department
+        
+        async_metadata_read = async_wrap(self.metadata_read)
+        
+        layout_metadata = await async_metadata_read('Layout', layout_name)
+        
+        def parse_layoutSections(layout_metadata):
+            layoutSections = pd.DataFrame(layout_metadata)
+            layoutSections['layoutColumns'] = layoutSections['layoutColumns'].apply(lambda row: list(filter(lambda item: item is not None, row)))
+            layoutSections = layoutSections.explode('layoutColumns').reset_index(drop=True)
+            layoutSections['layoutColumns'] = layoutSections['layoutColumns'].apply(lambda row: "" if str(row) == 'nan' else row['layoutItems'])
+            layoutSections = layoutSections.explode('layoutColumns').reset_index(drop=True)
+            layoutSections = pd.concat([layoutSections, layoutSections['layoutColumns'].apply(pd.Series, dtype=str).add_prefix('layoutColumns.')], axis=1).drop(['layoutColumns', "layoutColumns.0"], axis=1)
+            layoutSections.fillna("", inplace=True)
+            layoutSections.drop_duplicates(inplace=True)
+            return layoutSections
+
+        def parse_platformActionList(platformActionList_metadata):
+            platformActionList = pd.DataFrame(platformActionList_metadata)
+            platformActionList = pd.concat([platformActionList, platformActionList['platformActionListItems'].apply(pd.Series, dtype=str).add_prefix('platformActionListItems.')], axis=1).drop(['platformActionListItems'], axis=1)
+            return platformActionList
+
+
+        def parse_quickActionList(quickActionList_metadata):
+            quickActionList = pd.DataFrame(quickActionList_metadata)
+            quickActionList = pd.concat([quickActionList, quickActionList['quickActionListItems'].apply(pd.Series, dtype=str).add_prefix('quickActionListItems.')], axis=1).drop(['quickActionListItems'], axis=1)
+            return quickActionList
+
+        parsed_layout_metadata = {}
+        parsed_layout_metadata['customButtonsList'] = layout_metadata['customButtons'][0]
+        parsed_layout_metadata['excludeButtonsList'] = layout_metadata['excludeButtons'][0]
+        # Adding required fields from the main page layout gives you the final list of mini layout items
+        parsed_layout_metadata['miniLayoutDict'] = dict(layout_metadata['miniLayout'][0])
+        parsed_layout_metadata['layoutSectionsDataFrame'] = parse_layoutSections(layout_metadata['layoutSections'][0])
+        parsed_layout_metadata['platformActionListDataFrame'] = parse_platformActionList(layout_metadata['platformActionList'][0])
+        parsed_layout_metadata['quickActionListDataFrame'] = parse_quickActionList(layout_metadata['quickActionList'][0])
+        parsed_layout_metadata['relatedListDataFrame'] = pd.DataFrame(layout_metadata['relatedLists'][0])
+        return parsed_layout_metadata
+    
     ### ----------------------------------------------------------------------------------------------------
     ### Synchronous Metadata Functions
     ### ----------------------------------------------------------------------------------------------------
